@@ -29,7 +29,8 @@ class Recipe(object):
 
         self.gems = options['gems'].split()
         self.version = options.get('version')
-
+        # Allow to define specific ruby executable. If not, take just 'ruby'
+        self.ruby_executable = options.get('ruby-executable', 'ruby')
 
     def run(self, cmd, environ=None):
         """Run the given ``cmd`` in a child process."""
@@ -125,8 +126,9 @@ class Recipe(object):
                         '--no-rdoc',
                         '--no-ri',
                     ]),
+                'RUBY': self.ruby_executable,
             }
-            self.run('ruby setup.rb all %(OPTIONS)s' % s, env)
+            self.run('%(RUBY)s setup.rb all %(OPTIONS)s' % s, env)
         finally:
             shutil.rmtree(srcdir)
             os.chdir(current_dir)
